@@ -74,7 +74,6 @@ class JsctlTest(TestCaseHelper, TestCase):
         self.call(
             "sentinel register jaseci/jsctl/tests/ll.jac -name ll -set_active true"
         )
-        self.call("graph create -set_active true")
         self.call("walker run init")
         self.call("walker run gen_rand_life")
         r = self.call("graph get -mode dot")
@@ -83,7 +82,7 @@ class JsctlTest(TestCaseHelper, TestCase):
 
         r = self.call("graph get -mode dot -detailed true")
         self.assertIn('"n0" -> "n', r)
-        self.assertIn('week="', r)
+        self.assertIn('id="', r)
 
     def test_jsctl_aliases(self):
         """Tests that alias mapping api works"""
@@ -284,8 +283,6 @@ class JsctlTest(TestCaseHelper, TestCase):
         self.assertGreater(os.path.getsize("jaseci/jsctl/tests/teststest.jir"), 20000)
 
     def test_jsctl_jac_build_with_action(self):
-        import os
-
         if os.path.exists("jaseci/jsctl/tests/withaction.jir"):
             os.remove("jaseci/jsctl/tests/withaction.jir")
             self.assertFalse(os.path.exists("jaseci/jsctl/tests/withaction.jir"))
@@ -406,6 +403,29 @@ class JsctlTest(TestCaseHelper, TestCase):
         self.assertGreater(before, 4)
         self.assertGreater(after, before)
 
+    def test_jsctl_script(self):
+        r = self.call("script jaseci/jsctl/tests/jsctl_script")
+        self.assertEqual(r, "[]\n\n[]\n\n{}\n\n")
+
+    def test_jsctl_script_output(self):
+        self.call("script jaseci/jsctl/tests/jsctl_script -o scr_out")
+        with open("scr_out", "r") as f:
+            s = [line.rstrip() for line in f]
+        if os.path.exists("scr_out"):
+            os.remove("scr_out")
+        self.assertEqual(
+            s,
+            [
+                "Multi Command Script Output:",
+                "Output for sentinel list:",
+                "[]",
+                "Output for graph list:",
+                "[]",
+                "Output for alias list:",
+                "{}",
+            ],
+        )
+
 
 class JsctlTestWithSession(TestCaseHelper, TestCase):
     """Unit tests for Jac language"""
@@ -437,7 +457,3 @@ class JsctlTestWithSession(TestCaseHelper, TestCase):
         self.call("sentinel register jaseci/jsctl/tests/teststest.jac")
         r = self.call_cast("object get active:sentinel -detailed true")
         self.assertGreater(len(r["arch_ids"]), 3)
-
-    def test_jsctl_script(self):
-        r = self.call("script jaseci/jsctl/tests/jsctl_script")
-        self.assertEqual(r, "[]\n\n[]\n\n{}\n\n")
